@@ -247,10 +247,13 @@ class HydraPy:
     FATAL = 'fatal'
     TRACE = 'trace'
 
-    def __init__(self, config_path, version, message_handler):
+    def __init__(self, config_path, version, message_handler, queue_handler):
         if message_handler:
             self._message_handler = message_handler
 
+        if queue_handler:
+            self._queue_handler = message_handler
+
         with open(config_path, 'r', encoding='utf-8-sig') as json_file:
             self._config = json.load(json_file)
 
@@ -434,7 +437,7 @@ class HydraPy:
                 if self._message_handler:
                     msg = await channel.get_json()
                     msg = (UMF_Message()).create_message(msg)
-                    asyncio.ensure_future(self._message_handler(msg))
+                    asyncio.ensure_future(self._message_handler(msg, self))
 
         ch1 = await self._redis.subscribe(f'{self._mc_message_key}:{self._service_name}')
         ch2 = await self._redis.subscribe(f'{self._mc_message_key}:{self._service_name}:{self._instance_id}')
